@@ -216,7 +216,7 @@ class AimRepo:
                 'active_branch': '',
             }))
 
-        self.create_logs()
+        # self.create_logs()
         self.create_branch(AIM_DEFAULT_BRANCH_NAME)
         self.checkout_branch(AIM_DEFAULT_BRANCH_NAME)
 
@@ -789,22 +789,72 @@ class AimRepo:
         commit_path = os.path.join(self.path, branch, commit)
         return ls_dir([commit_path])
 
-    def select_run_metrics(self, experiment_name: str, run_hash: str,
-                           select_metrics: Union[str, List[str], Tuple[str]]
-                           ) -> Optional[Run]:
-        if not self.run_exists(experiment_name, run_hash):
-            return None
+    def select_runs(self,
+                    expression: Optional[
+                           Union[str,
+                                 Expression,
+                                 BinaryExpressionTree]] = None,
+                    default_expression: Optional[
+                           Union[str,
+                                 Expression,
+                                 BinaryExpressionTree]] = None,
+                    ) -> List[Run]:
+        runs = {
+            exp_name: [
+                Run(self, exp_name, run_hash)
+                for run_hash in self.list_branch_commits(exp_name)
+            ]
+            for exp_name in self.list_branches()
+        }
 
-        if isinstance(select_metrics, str):
-            select_metrics = [select_metrics]
+        matched_runs: List[Run] = []
 
-        run = Run(self, experiment_name, run_hash)
-        for metric_name, metric in run.get_all_metrics().items():
-            if metric_name in select_metrics:
-                for trace in metric.get_all_traces():
-                    metric.append(trace)
-                    run.add(metric)
-        return run
+        # Build expression trees
+        if expression:
+            expression = build_bet(expression)
+            expression.strict = True
+
+        if default_expression:
+            default_expression = build_bet(default_expression)
+            default_expression.strict = True
+            if expression:
+                expression.concat(default_expression)
+            else:
+                expression = default_expression
+
+        for experiment_runs in runs.values():
+            for run in experiment_runs:
+                # Add metrics path modifier
+                expression.dump_path_modifiers()
+                if AIM_MAP_METRICS_KEYWORD in run.params.keys():
+                    expression.add_path_modifier(
+                        lambda path_token: self.metrics_path_checker(
+                            path_token,
+                            run.config.keys()),
+                        lambda path_token: self.metrics_path_modifier(
+                            path_token,
+                            run.params[AIM_MAP_METRICS_KEYWORD])
+                    )
+
+                # Dictionary representing all search fields
+                fields = {
+                    'experiment': run.experiment_name,
+                    'run': run.config,  # Run configs (date, name, archived etc)
+                    'params': run.params,  # Run parameters (`NestedMap`)
+                }
+                # Default parameters - ones passed without namespace
+                default_params = run.params.get(AIM_NESTED_MAP_DEFAULT) or {}
+
+                if not expression:
+                    res = True
+                else:
+                    res = expression.match(fields,
+                                           run.params,
+                                           default_params)
+                if res is True:
+                    matched_runs.append(run)
+
+        return matched_runs
 
     def select_metrics(self, select_metrics: Union[str, List[str], Tuple[str]],
                        expression: Optional[
@@ -840,6 +890,18 @@ class AimRepo:
 
         for experiment_runs in runs.values():
             for run in experiment_runs:
+                # Add metrics path modifier
+                expression.dump_path_modifiers()
+                if AIM_MAP_METRICS_KEYWORD in run.params.keys():
+                    expression.add_path_modifier(
+                        lambda path_token: self.metrics_path_checker(
+                            path_token,
+                            run.config.keys()),
+                        lambda path_token: self.metrics_path_modifier(
+                            path_token,
+                            run.params[AIM_MAP_METRICS_KEYWORD])
+                    )
+
                 # Dictionary representing all search fields
                 fields = {
                     'experiment': run.experiment_name,
@@ -872,6 +934,66 @@ class AimRepo:
 
         return matched_runs
 
+    @staticmethod
+    def metrics_path_checker(path, run_fields: list) -> bool:
+        path = str(path)
+        if not path.startswith('run.'):
+            return False
+
+        identifiers = path.split('.')[1:]
+        if len(identifiers) == 0 or identifiers[0] in run_fields:
+            return False
+
+        return True
+
+    @staticmethod
+    def metrics_path_modifier(path, metrics) -> Optional[bool]:
+        path = str(path)
+
+        if '.' not in path:
+            return None
+
+        identifiers = path.split('.')
+        if len(identifiers) < 2:
+            return None
+
+        metric_name = identifiers[1]
+        if len(identifiers) > 2 and identifiers[-1] in ('min', 'max', 'last'):
+            value_field = identifiers[-1]
+            identifiers = identifiers[:-1]
+        else:
+            value_field = 'last'
+
+        context_identifiers = identifiers[2:]
+
+        if metric_name not in metrics:
+            return None
+
+        metric_data = metrics[metric_name]
+        for trace in metric_data:
+            context_values = list(map(lambda c: c[1], trace['context']))
+            if all(c in context_values for c in context_identifiers):
+                return trace['values'][value_field]
+
+        return None
+
+    def select_run_metrics(self, experiment_name: str, run_hash: str,
+                           select_metrics: Union[str, List[str], Tuple[str]]
+                           ) -> Optional[Run]:
+        if not self.run_exists(experiment_name, run_hash):
+            return None
+
+        if isinstance(select_metrics, str):
+            select_metrics = [select_metrics]
+
+        run = Run(self, experiment_name, run_hash)
+        for metric_name, metric in run.get_all_metrics().items():
+            if metric_name in select_metrics:
+                for trace in metric.get_all_traces():
+                    metric.append(trace)
+                    run.add(metric)
+        return run
+
     def create_logs(self):
         """
         Creates the logs dir in .aim to store error and activity logs
